Class: Protest::Runner
- Inherits:
-
Object
- Object
- Protest::Runner
- Defined in:
- lib/protest/runner.rb
Instance Method Summary collapse
-
#initialize(report) ⇒ Runner
constructor
Set up the test runner.
-
#report(test) ⇒ Object
Run a test and report if it passes, fails, or is pending.
-
#run(*test_cases) ⇒ Object
Run a set of test cases, provided as arguments.
Constructor Details
#initialize(report) ⇒ Runner
Set up the test runner. Takes in a report that will be passed to test cases for reporting.
5 6 7 |
# File 'lib/protest/runner.rb', line 5 def initialize(report) @report = report end |
Instance Method Details
#report(test) ⇒ Object
Run a test and report if it passes, fails, or is pending. Takes the name of the test as an argument.
24 25 26 27 28 29 30 31 32 33 34 |
# File 'lib/protest/runner.rb', line 24 def report(test) fire_event(:test, Test.new(test)) test.run(@report) fire_event(:pass, PassedTest.new(test)) rescue Pending => e fire_event :pending, PendingTest.new(test, e) rescue AssertionFailed => e fire_event :failure, FailedTest.new(test, e) rescue Exception => e fire_event :error, ErroredTest.new(test, e) end |
#run(*test_cases) ⇒ Object
Run a set of test cases, provided as arguments. This will fire relevant
events on the runner's report, at the start and end of the test run,
and before and after each test case (+enter+ and exit.)
12 13 14 15 16 17 18 19 20 |
# File 'lib/protest/runner.rb', line 12 def run(*test_cases) fire_event :start test_cases.each do |test_case| fire_event :enter, test_case test_case.run(self) fire_event :exit, test_case end fire_event :end end |