Class: Protest::Reports::Summary
- Inherits:
-
Protest::Report
- Object
- Protest::Report
- Protest::Reports::Summary
- Defined in:
- lib/protest/reports/summary.rb
Overview
The :summary report will output a brief summary with the total number
of tests, assertions, passed tests, pending tests, failed tests and
errors.
Instance Attribute Summary
Attributes inherited from Protest::Report
Method Summary
Methods inherited from Protest::Report
#add_assertion, #assertions, #errors, #failures, #failures_and_errors, #initialize, on, #passes, #pendings, #tests, #time_elapsed, #total_tests
Methods included from Utils::ColorfulOutput
Methods included from Utils::Summaries
#summarize_errors, #summarize_pending_tests, #summarize_test_totals
Constructor Details
This class inherits a constructor from Protest::Report